======================================
Welcome to uhammers's documentation!
======================================

.. include:: ../README.rst

Contents
--------

.. toctree::
   :maxdepth: 1

   installation
   usage
   modules
   authors
   history




Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
